@@ -20,6 +20,10 @@ class Event(object):
         self.type = type_
         self.data = data
 
+        if type_ == EventType.NEW_MESSAGE:
+            self.text = data['text']
+            self.from_chat = data['chat']['chatId']
+            self.message_author = data['from']
+        
     def __repr__(self):
         return "Event(type='{self.type}', data='{self.data}')".format(self=self)
-
